==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/language/japanese/modinfo.php <==
<?php

$constpref = '_MI_'.strtoupper($mydirname);

if(!defined($constpref.'_LOADED')){

define($constpref.'_LOADED', 1);

define($constpref.'_MODULE_DESC', 'SNSXOOPSΩ夲뤳ȤǤ⥸塼Ǥ');

define($constpref.'_MENU_MYPAGE', 'ޥڡ');

define($constpref.'_BLOCK_RECENT_TOPIC', 'ǿȥԥå');

define($constpref.'_AD_MENU_CATEGORY', 'ߥ˥ƥƥ');
define($constpref.'_AD_MENU_IMAGE', '');
define($constpref.'_AD_MENU_FILE', 'ե');
define($constpref.'_AD_MENU_ACCESS', '');

define($constpref.'_COMMU_NOTIFY', 'ɽΥߥ˥ƥ');
define($constpref.'_COMMU_NOTIFY_DSC', 'ɽΥߥ˥ƥФΥץ');

define($constpref.'_TOPIC_CREATE_NOTIFY', 'ȥԥå');
define($constpref.'_TOPIC_CREATE_NOTIFY_CAP', '˥ȥԥå줿Τ');
define($constpref.'_TOPIC_CREATE_NOTIFY_DSC', '˥ȥԥå줿Τ');
define($constpref.'_TOPIC_CREATE_NOTIFY_SBJ', '[{X_SITENAME}] {X_MODULE}: ˥ȥԥåޤ');

define($constpref.'_TOPIC_POST_NOTIFY', '');
define($constpref.'_TOPIC_POST_NOTIFY_CAP', 'ȥԥåФƥȤƤ줿Τ');
define($constpref.'_TOPIC_POST_NOTIFY_DSC', 'ȥԥåФƥȤƤ줿Τ');
define($constpref.'_TOPIC_POST_NOTIFY_SBJ', '[{X_SITENAME}] {X_MODULE}: ˥ȤƤޤ');

define($constpref.'_FPATH', '/եΥåץǥ쥯ȥ');
define($constpref.'_FPATHDSC', 'åץɤ/եƤ¸ޤ<br><span style="color:#ff0000;"> ƥΤᡢФθǥ쥯ȥ곰ξꤷƤ</span>');

define($constpref.'_FSIZE', '/եκ祵 [bytes]');
define($constpref.'_FSIZEDSC', 'åץɤ/եκ祵Хñ̤ǻꤷƤ');

define($constpref.'_FMIME', 'åץɤĤեMIME');
define($constpref.'_FMIMEDSC', 'åץɤĤեMIMEפäǶڤäϤƤ');

define($constpref.'_IMGW', 'κ [pixel]');
define($constpref.'_IMGWDSC', '');

define($constpref.'_IMGH', 'κ⤵ [pixel]');
define($constpref.'_IMGHDSC', '');

define($constpref.'_BLOG', '֥⥸塼');
define($constpref.'_BLOGDSC', 'Ѥ֥⥸塼򤷤Ƥ<br>⥸塼뤬󥹥ȡ뤵ƤʤѤǤޤ');
define($constpref.'_BLOG0', 'Ѥʤ');
define($constpref.'_BLOG1', '֥');
define($constpref.'_BLOG2', '֥D3');
define($constpref.'_BLOG3', 'WordPress ME (for XOOPS2)');

define($constpref.'_BLOGDIR', '֥⥸塼Υǥ쥯ȥ̾');
define($constpref.'_BLOGDIRDSC', '֥⥸塼Υǥ쥯ȥ̾ѹƤϡͤϤƤ<br>ˤϥǥեȤΥǥ쥯ȥ̾ˤʤޤ');

define($constpref.'_MYPAGE', 'Ⱦڡޥڡ֤');
define($constpref.'_MYPAGEDSC', 'XOOPSɸΥȾڡ򡢥ߥ˥ƥ⥸塼Ѥòޥڡ֤뤳ȤǤޤ<br><br>XOOPS 2.0Ϥξ硢[Ϥ]򤹤ȰʲΥեƤѹޤᤷϺ[]򤷤Ƥ<br>&nbsp;'.XOOPS_ROOT_PATH.'/userinfo.php<br>&nbsp;'.XOOPS_ROOT_PATH.'/edituser.php');

define($constpref.'_POPMAX', '͵٤Υ');
define($constpref.'_POPMAXDSC', '͵٤ͤĶȣ(ǹ)ˤʤޤ<br>桼εϤ˱ѹƤ<br><br><span style="color:#0000ff;">͵١оݥߥ˥ƥؤΥʿ͡ʲ30</span>');

define($constpref.'_FREQMAX', '٤Υ');
define($constpref.'_FREQMAXDSC', '٤ͤĶȣ(ǹ)ˤʤޤ<br>桼εϤ˱ѹƤ<br><br><span style="color:#0000ff;">١оݥߥ˥ƥƤ줿ȥԥåӥȤοʿ͡ʲ30</span>');

define($constpref.'_FOOT', 'ȵǽѤ');
define($constpref.'_FOOTDSC', 'ޥڡФ륢ǽѤ뤫ɤꤷޤ');

define($constpref.'_INSTERR', '<span style="color:#ff0000;"><b>⥸塼Υǥ쥯ȥ̾ʸξ¤15ʸǤ<br />ö⥸塼򥢥󥤥󥹥ȡ뤷15ʸΥǥ쥯ȥ̾ѹ塢٥󥹥ȡ뤷Ƥ<br /></b></span>');

}

?>

==> xsns_1.0.4.zip: xsns_1.0.4/xoops_trust_path/modules/xsns/language/japanese/modinfo.php <==
<?php

$constpref = '_MI_'.strtoupper($mydirname);

if(!defined($constpref.'_LOADED')){

define($constpref.'_LOADED', 1);

define($constpref.'_MODULE_DESC', 'SNSXOOPSΩ夲뤳ȤǤ⥸塼Ǥ');

define($constpref.'_MENU_MYPAGE', 'ޥڡ');

define($constpref.'_BLOCK_RECENT_TOPIC', 'ǿȥԥå');

define($constpref.'_AD_MENU_CATEGORY', 'ߥ˥ƥƥ');
define($constpref.'_AD_MENU_IMAGE', '');
define($constpref.'_AD_MENU_FILE', 'ե');
define($constpref.'_AD_MENU_ACCESS', '');

define($constpref.'_COMMU_NOTIFY', 'ɽΥߥ˥ƥ');
define($constpref.'_COMMU_NOTIFY_DSC', 'ɽΥߥ˥ƥФΥץ');

define($constpref.'_TOPIC_CREATE_NOTIFY', 'ȥԥå');
define($constpref.'_TOPIC_CREATE_NOTIFY_CAP', '˥ȥԥå줿Τ');
define($constpref.'_TOPIC_CREATE_NOTIFY_DSC', '˥ȥԥå줿Τ');
define($constpref.'_TOPIC_CREATE_NOTIFY_SBJ', '[{X_SITENAME}] {X_MODULE}: ˥ȥԥåޤ');

define($constpref.'_TOPIC_POST_NOTIFY', '');
define($constpref.'_TOPIC_POST_NOTIFY_CAP', 'ȥԥåФƥȤƤ줿Τ');
define($constpref.'_TOPIC_POST_NOTIFY_DSC', 'ȥԥåФƥȤƤ줿Τ');
define($constpref.'_TOPIC_POST_NOTIFY_SBJ', '[{X_SITENAME}] {X_MODULE}: ˥ȤƤޤ');

define($constpref.'_FPATH', '/եΥåץǥ쥯ȥ');
define($constpref.'_FPATHDSC', 'åץɤ/եƤ¸ޤ<br><span style="color:#ff0000;"> ƥΤᡢФθǥ쥯ȥ곰ξꤷƤ</span>');

define($constpref.'_FSIZE', '/եκ祵 [bytes]');
define($constpref.'_FSIZEDSC', 'åץɤ/եκ祵Хñ̤ǻꤷƤ');

define($constpref.'_FMIME', 'åץɤĤեMIME');
define($constpref.'_FMIMEDSC', 'åץɤĤեMIMEפäǶڤäϤƤ');

define($constpref.'_IMGW', 'κ [pixel]');
define($constpref.'_IMGWDSC', '');

define($constpref.'_IMGH', 'κ⤵ [pixel]');
define($constpref.'_IMGHDSC', '');

define($constpref.'_BLOG', '֥⥸塼');
define($constpref.'_BLOGDSC', 'Ѥ֥⥸塼򤷤Ƥ<br>⥸塼뤬󥹥ȡ뤵ƤʤѤǤޤ');
define($constpref.'_BLOG0', 'Ѥʤ');
define($constpref.'_BLOG1', '֥');
define($constpref.'_BLOG2', '֥D3');
define($constpref.'_BLOG3', 'WordPress ME (for XOOPS2)');

define($constpref.'_BLOGDIR', '֥⥸塼Υǥ쥯ȥ̾');
define($constpref.'_BLOGDIRDSC', '֥⥸塼Υǥ쥯ȥ̾ѹƤϡͤϤƤ<br>ˤϥǥեȤΥǥ쥯ȥ̾ˤʤޤ');

define($constpref.'_MYPAGE', 'Ⱦڡޥڡ֤');
define($constpref.'_MYPAGEDSC', 'XOOPSɸΥȾڡ򡢥ߥ˥ƥ⥸塼Ѥòޥڡ֤뤳ȤǤޤ<br><br>XOOPS 2.0Ϥξ硢[Ϥ]򤹤ȰʲΥեƤѹޤᤷϺ[]򤷤Ƥ<br>&nbsp;'.XOOPS_ROOT_PATH.'/userinfo.php<br>&nbsp;'.XOOPS_ROOT_PATH.'/edituser.php');

define($constpref.'_POPMAX', '͵٤Υ');
define($constpref.'_POPMAXDSC', '͵٤ͤĶȣ(ǹ)ˤʤޤ<br>桼εϤ˱ѹƤ<br><br><span style="color:#0000ff;">͵١оݥߥ˥ƥؤΥʿ͡ʲ30</span>');

define($constpref.'_FREQMAX', '٤Υ');
define($constpref.'_FREQMAXDSC', '٤ͤĶȣ(ǹ)ˤʤޤ<br>桼εϤ˱ѹƤ<br><br><span style="color:#0000ff;">١оݥߥ˥ƥƤ줿ȥԥåӥȤοʿ͡ʲ30</span>');

define($constpref.'_FOOT', 'ȵǽѤ');
define($constpref.'_FOOTDSC', 'ޥڡФ륢ǽѤ뤫ɤꤷޤ');

define($constpref.'_INSTERR', '<span style="color:#ff0000;"><b>⥸塼Υǥ쥯ȥ̾ʸξ¤15ʸǤ<br />ö⥸塼򥢥󥤥󥹥ȡ뤷15ʸΥǥ쥯ȥ̾ѹ塢٥󥹥ȡ뤷Ƥ<br /></b></span>');

define($constpref.'_CATEGORY', 'ƥ');
define($constpref.'_CATEGORY_1', '̣');
define($constpref.'_CATEGORY_2', '');
define($constpref.'_CATEGORY_3', '٥');
define($constpref.'_CATEGORY_4', '¾');

}

?>
